diff --git a/frontend/src/components/secret-syncs/forms/SecretSyncReviewFields/CamundaSyncReviewFields.tsx b/frontend/src/components/secret-syncs/forms/SecretSyncReviewFields/CamundaSyncReviewFields.tsx
index 53aacae40..483aa67fb 100644
--- a/frontend/src/components/secret-syncs/forms/SecretSyncReviewFields/CamundaSyncReviewFields.tsx
+++ b/frontend/src/components/secret-syncs/forms/SecretSyncReviewFields/CamundaSyncReviewFields.tsx
@@ -13,7 +13,7 @@ export const CamundaSyncReviewFields = () => {
<>
{scope}
- {clusterName} (uuid:{clusterUUID})
+ {clusterName} (id:{clusterUUID})
>
);
diff --git a/backend/src/services/app-connection/camunda/camunda-connection-fns.ts b/backend/src/services/app-connection/camunda/camunda-connection-fns.ts
index da6ba53f2..90d9744b8 100644
--- a/backend/src/services/app-connection/camunda/camunda-connection-fns.ts
+++ b/backend/src/services/app-connection/camunda/camunda-connection-fns.ts
@@ -46,8 +46,8 @@ export const getCamundaConnectionAccessToken = async (
) => {
const { clientSecret, clientId, accessToken, expiresAt } = credentials;
- // get new token if less than 10 minutes from expiry
- if (Date.now() < expiresAt - 10_000) {
+ // get new token if less than 30 seconds from expiry
+ if (Date.now() < expiresAt - 30_000) {
return accessToken;
}